"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseApi = void 0;
const axios_1 = __importDefault(require("axios"));
const https_1 = __importDefault(require("https"));
const config_1 = require("./config");
const logger_1 = require("../utils/logger");
const errors_1 = require("../utils/errors");
class BaseApi {
    constructor(baseUrl, creds, getJwt) {
        var _a, _b, _c;
        this.baseUrl = baseUrl;
        this.creds = creds;
        this.getJwt = getJwt;
        const headers = {
            'User-Agent': config_1.API_CONFIG.USER_AGENT,
            Accept: config_1.API_CONFIG.ACCEPT,
            'Content-Type': config_1.API_CONFIG.CONTENT_TYPE,
            JwtAuth: '',
        };
        if ((_a = this.creds) === null || _a === void 0 ? void 0 : _a.token) {
            headers.JwtAuth = config_1.API_CONFIG.AUTHORIZATION((_b = this.creds) === null || _b === void 0 ? void 0 : _b.token);
        }
        if (getJwt) {
            headers.JwtAuth = config_1.API_CONFIG.AUTHORIZATION(getJwt());
        }
        const BaseUrl = ((_c = this.creds) === null || _c === void 0 ? void 0 : _c.server) || baseUrl;
        this.api = axios_1.default.create({
            baseURL: `${BaseUrl}/${config_1.API_CONFIG.API_URL}`,
            headers,
            httpsAgent: new https_1.default.Agent({ rejectUnauthorized: config_1.API_CONFIG.DEFAULT_REJECT_UNAUTH }),
            timeout: config_1.API_CONFIG.DEFAULT_TIMEOUT,
        });
    }
    updateJWT(jwtToken) {
        this.api.defaults.headers.Authorization = config_1.API_CONFIG.AUTHORIZATION(jwtToken);
    }
    request(config) {
        return __awaiter(this, void 0, void 0, function* () {
            (0, logger_1.info)('Sending API Request to PAM ...');
            try {
                const response = yield this.api.request(config);
                return response.data;
            }
            catch (error) {
                throw new errors_1.PAMError(`API request failed: ${error.message}`);
            }
        });
    }
    get(url, params) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                method: 'GET',
                url,
                params,
            };
            return this.request(config);
        });
    }
    post(url, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                method: 'POST',
                url,
                data,
            };
            return this.request(config);
        });
    }
    resolveResponse(response, errorMessage) {
        if ((response === null || response === void 0 ? void 0 : response.return_code) === 1000) {
            return response;
        }
        else if ((response === null || response === void 0 ? void 0 : response.return_code) === 1009) {
            response.message = `Your Session has expired Please login again using "revbits-pam-cli auth" command`;
        }
        throw new errors_1.PAMError(errorMessage, response);
    }
    sendApiRequest(endpoint, requestData, errorMessage) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.post(endpoint, requestData);
            return this.resolveResponse(response, errorMessage);
        });
    }
}
exports.BaseApi = BaseApi;
