"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthCli = void 0;
const commander_1 = require("commander");
const auth_config_1 = require("./auth.config");
const base_cli_1 = require("../base.cli");
const auth_1 = __importDefault(require("../../api/auth"));
const keychain_1 = require("../../utils/keychain");
const logger_1 = require("../../utils/logger");
const ask_1 = require("../../utils/ask");
const translations_1 = require("../../constants/translations");
class AuthCli extends base_cli_1.BaseCLI {
    constructor(program, creds) {
        super(program, creds);
    }
    prepare() {
        return __awaiter(this, void 0, void 0, function* () {
            this.auth();
            this.logout();
        });
    }
    auth() {
        this.design(auth_config_1.COMMANDS, 'auth')
            .addOption(new commander_1.Option('-h, --host <string>', auth_config_1.COMMANDS.auth.options.serverURL.description))
            .addOption(new commander_1.Option('-u, --username <string>', auth_config_1.COMMANDS.auth.options.username.description))
            .addOption(new commander_1.Option('-p, --password <string>', auth_config_1.COMMANDS.auth.options.password.description))
            .addOption(new commander_1.Option('-i, --iteration-count <number>', auth_config_1.COMMANDS.auth.options.itr.description))
            .action((_options) => {
            const options = (0, ask_1.askForPAMCreds)(_options);
            this.authenticate(options.host, options.username, options.password, options.iterationCount);
        });
    }
    logout() {
        this.design(auth_config_1.COMMANDS, 'logout').action(() => __awaiter(this, void 0, void 0, function* () {
            const creds = yield (0, keychain_1.retrieveCredentials)();
            if (creds) {
                const authApi = new auth_1.default(creds.server);
                authApi.logout(creds.token);
                yield (0, keychain_1.removeCredentials)();
                (0, logger_1.success)(translations_1.TRANSLATIONS.loggedOutSuccessfully);
            }
            else {
                (0, logger_1.warn)(translations_1.TRANSLATIONS.noSessionExists);
            }
        }));
    }
}
exports.AuthCli = AuthCli;
