"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseCLI = void 0;
const auth_1 = __importDefault(require("../api/auth"));
const utils_1 = require("../utils");
const keychain_1 = require("../utils/keychain");
const logger_1 = require("../utils/logger");
class BaseCLI {
    constructor(program, creds, config = null) {
        this.program = program;
        this.creds = creds;
        if (config) {
            this.commander = this.program.command(config.__main.command).description(config.__main.description);
        }
        else {
            this.commander = this.program;
        }
    }
    make(command, description) {
        return this.commander.command(command).description(description);
    }
    design(config, key) {
        return this.make(config[key].command, config[key].description);
    }
    authenticate(server, username, password, iterationCount) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const authApi = new auth_1.default(server);
            const loginResponse = yield authApi
                .login({
                email: username,
                password: (0, utils_1.getHashedPassword)(password, iterationCount),
            })
                .catch(() => { });
            if ((_a = loginResponse === null || loginResponse === void 0 ? void 0 : loginResponse.data) === null || _a === void 0 ? void 0 : _a.token) {
                yield (0, keychain_1.saveCredentials)(server, username, loginResponse.data.token);
                (0, logger_1.success)('Logged In Successfully.');
            }
        });
    }
    fetchAllResults(apiClass, options, apiFn, offset = 0, results = []) {
        return __awaiter(this, void 0, void 0, function* () {
            const limit = 100;
            const api = new apiClass(this.creds);
            const response = yield apiFn(api, options, limit, offset).catch(() => { });
            if (response && response.length > 0) {
                results = results.concat(response);
                if (response.length === limit) {
                    return this.fetchAllResults(apiClass, options, apiFn, offset + limit, results);
                }
            }
            return results;
        });
    }
    copy(text, type = 'Password') {
        return __awaiter(this, void 0, void 0, function* () {
            (0, logger_1.success)(`\nYour ${type} is: ${text}\n`);
        });
    }
}
exports.BaseCLI = BaseCLI;
