"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BreakGlassCli = void 0;
const commander_1 = require("commander");
const base_cli_1 = require("../base.cli");
const break_glass_config_1 = require("./break-glass.config");
const break_glass_1 = __importDefault(require("../../api/break-glass"));
const cli_table_1 = require("../../utils/cli-table");
const break_glass_entry_1 = __importDefault(require("../../api/break-glass-entry"));
const translations_1 = require("../../constants/translations");
class BreakGlassCli extends base_cli_1.BaseCLI {
    constructor(program, creds) {
        super(program, creds, break_glass_config_1.COMMANDS);
    }
    prepare() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.list();
            yield this.listAccounts();
            yield this.copyPassword();
        });
    }
    list() {
        return __awaiter(this, void 0, void 0, function* () {
            this.design(break_glass_config_1.COMMANDS, 'list').action(() => __awaiter(this, void 0, void 0, function* () {
                const api = new break_glass_1.default(this.creds);
                const res = yield api.getAll({}).catch(() => { });
                if (res && res.data) {
                    const table = new cli_table_1.CliTable(translations_1.TRANSLATIONS.breakGlasses, {
                        headings: {
                            id: { display: translations_1.TRANSLATIONS.id },
                            name: { display: translations_1.TRANSLATIONS.name, width: 35 },
                            description: { display: translations_1.TRANSLATIONS.description, truncate: true, truncateLength: 80, width: 40 },
                            created_at: { display: translations_1.TRANSLATIONS.createdAt, type: 'datetime' },
                            updated_at: { display: translations_1.TRANSLATIONS.updatedAt, type: 'datetime' },
                        },
                    });
                    table.print(res.data);
                }
            }));
        });
    }
    listAccounts() {
        return __awaiter(this, void 0, void 0, function* () {
            this.design(break_glass_config_1.COMMANDS, 'listAccounts')
                .addOption(new commander_1.Option('-i, --id <string>', break_glass_config_1.COMMANDS.listAccounts.options.breakGlassId.description).makeOptionMandatory(true))
                .action((options) => __awaiter(this, void 0, void 0, function* () {
                const results = yield this.fetchAllResults(break_glass_entry_1.default, options, (api, options, limit, offset) => __awaiter(this, void 0, void 0, function* () {
                    var _a;
                    const response = yield api.getAllAccounts({ secureContainerId: options.id, limit, offset }).catch(() => { });
                    return ((_a = response === null || response === void 0 ? void 0 : response.data) === null || _a === void 0 ? void 0 : _a.rows) || [];
                }));
                const table = new cli_table_1.CliTable(translations_1.TRANSLATIONS.breakGlassEntries, {
                    headings: {
                        id: { display: translations_1.TRANSLATIONS.id },
                        name: { display: translations_1.TRANSLATIONS.name, width: 25 },
                        username: { display: translations_1.TRANSLATIONS.username, width: 45 },
                        createdAt: { display: translations_1.TRANSLATIONS.createdAt, type: 'datetime' },
                        updatedAt: { display: translations_1.TRANSLATIONS.updatedAt, type: 'datetime' },
                    },
                });
                const mappedResults = results.map((r) => {
                    var _a, _b;
                    const username = ((_a = r.ldapAccount) === null || _a === void 0 ? void 0 : _a.username) || ((_b = r.linuxDiscoveredAccount) === null || _b === void 0 ? void 0 : _b.username);
                    return Object.assign(Object.assign({}, r), { username });
                });
                table.print(mappedResults);
            }));
        });
    }
    copyPassword() {
        return __awaiter(this, void 0, void 0, function* () {
            this.design(break_glass_config_1.COMMANDS, 'copyPassword')
                .addOption(new commander_1.Option('-i, --id <string>', break_glass_config_1.COMMANDS.copyPassword.options.accountId.description).makeOptionMandatory(true))
                .action((options) => __awaiter(this, void 0, void 0, function* () {
                const api = new break_glass_entry_1.default(this.creds);
                const res = yield api.copyAccountPassword({ id: options.id, action: 'copied-password' });
                if (res && res.data) {
                    this.copy(res.data.password);
                }
            }));
        });
    }
}
exports.BreakGlassCli = BreakGlassCli;
