"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CLI = void 0;
const commander_1 = require("commander");
const auth_cli_1 = require("./auth/auth.cli");
const utils_1 = require("../utils");
const keychain_1 = require("../utils/keychain");
const logger_1 = require("../utils/logger");
const secret_manager_cli_1 = require("./secret-manager/secret-manager.cli");
const break_glass_cli_1 = require("./break-glass/break-glass.cli");
class CLI {
    constructor() {
        this.program = new commander_1.Command();
    }
    prepare() {
        return __awaiter(this, void 0, void 0, function* () {
            const packageContent = (0, utils_1.readPackageJSON)();
            if (packageContent) {
                this.program.name(packageContent.name).version(packageContent.version).description(packageContent.description);
                yield this.designCommands();
                this.program.parse(process.argv);
            }
        });
    }
    designCommands() {
        return __awaiter(this, void 0, void 0, function* () {
            const creds = yield (0, keychain_1.retrieveCredentials)();
            yield this.auth(creds);
            yield this.secretManager(creds);
            yield this.breakGlass(creds);
            this.program.command('test').action(() => __awaiter(this, void 0, void 0, function* () {
                const creds = yield (0, keychain_1.retrieveCredentials)();
                (0, logger_1.success)('saved creds are ');
                console.log(creds);
            }));
        });
    }
    auth(creds) {
        return __awaiter(this, void 0, void 0, function* () {
            const cli = new auth_cli_1.AuthCli(this.program, creds);
            yield cli.prepare();
        });
    }
    secretManager(creds) {
        return __awaiter(this, void 0, void 0, function* () {
            const cli = new secret_manager_cli_1.SecretManagerCli(this.program, creds);
            yield cli.prepare();
        });
    }
    breakGlass(creds) {
        return __awaiter(this, void 0, void 0, function* () {
            const cli = new break_glass_cli_1.BreakGlassCli(this.program, creds);
            yield cli.prepare();
        });
    }
}
exports.CLI = CLI;
