"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecretManagerCli = void 0;
const commander_1 = require("commander");
const pam_secretman_js_plugin_1 = require("@revbits/pam-secretman-js-plugin");
const base_cli_1 = require("../base.cli");
const secret_manager_config_1 = require("./secret-manager.config");
const logger_1 = require("../../utils/logger");
const translations_1 = require("../../constants/translations");
class SecretManagerCli extends base_cli_1.BaseCLI {
    constructor(program, creds) {
        super(program, creds, secret_manager_config_1.COMMANDS);
    }
    prepare() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.fetch();
        });
    }
    fetch() {
        return __awaiter(this, void 0, void 0, function* () {
            let host = null;
            if (this.creds && this.creds.server) {
                host = this.creds.server;
            }
            this.design(secret_manager_config_1.COMMANDS, 'fetch')
                .addOption(new commander_1.Option('-h, --host <string>', secret_manager_config_1.COMMANDS.fetch.options.host.description).makeOptionMandatory(!host))
                .addOption(new commander_1.Option('-s, --secret <string>', secret_manager_config_1.COMMANDS.fetch.options.secret.description).makeOptionMandatory(true))
                .addOption(new commander_1.Option('-k, --api-key <string>', secret_manager_config_1.COMMANDS.fetch.options.apiKey.description).makeOptionMandatory(true))
                .action((_options) => __awaiter(this, void 0, void 0, function* () {
                try {
                    const secrets = _options.secret.split(',').map((str) => str.trim());
                    const p = secrets.map((secret) => __awaiter(this, void 0, void 0, function* () {
                        try {
                            const value = yield (0, pam_secretman_js_plugin_1.generateSecret)(_options.host || host, secret, _options.apiKey);
                            (0, logger_1.success)(`${secret}: ${value}`);
                        }
                        catch (err) {
                            (0, logger_1.error)(`${secret}: ${translations_1.TRANSLATIONS.invalidApiOrSecretKey}`);
                        }
                    }));
                    yield Promise.all(p);
                }
                catch (err) {
                    (0, logger_1.error)(translations_1.TRANSLATIONS.invalidApiOrSecretKey);
                }
            }));
        });
    }
}
exports.SecretManagerCli = SecretManagerCli;
