"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.askForPAMCreds = exports.askQuestion = void 0;
const readline_sync_1 = __importDefault(require("readline-sync"));
const chalk_1 = __importDefault(require("chalk"));
const logger_1 = require("./logger");
const auth_config_1 = require("../cli/auth/auth.config");
const questionsTitle = (title) => {
    (0, logger_1.blue)(`\n${title}`);
    (0, logger_1.success)(`**************************************************\n`);
};
const logQuestion = (_question, defaultValue = null, options = {}) => {
    let question = chalk_1.default.green.bold(_question);
    if (options.allowedValues) {
        question += ` (${options.allowedValues.join(', ')})`;
    }
    if (defaultValue) {
        question += ' ' + chalk_1.default.blue.bold(`[Default: ${options.hideEchoBack ? '******' : defaultValue}]`);
    }
    question += ' : ';
    return question;
};
const askQuestion = (question, _defaultInput = null, options = {}, fn = 'question') => {
    const defaultInput = _defaultInput && _defaultInput !== 'undefined' ? _defaultInput : undefined;
    const input = readline_sync_1.default[fn](logQuestion(question, defaultInput, options), Object.assign({ defaultInput }, options));
    if (options.allowedValues) {
        if (!options.allowedValues.includes(input)) {
            (0, logger_1.error)(`Please enter input from ${options.allowedValues.join(', ')}`);
            return null;
        }
    }
    return input;
};
exports.askQuestion = askQuestion;
const askForPAMCreds = (data) => {
    if (!(data.host && data.username && data.password && data.iterationCount)) {
        questionsTitle('PAM Creds');
    }
    while (!data.host) {
        data.host = (0, exports.askQuestion)(auth_config_1.COMMANDS.auth.options.serverURL.description);
    }
    while (!data.username) {
        data.username = (0, exports.askQuestion)(auth_config_1.COMMANDS.auth.options.username.description);
    }
    while (!data.password) {
        data.password = (0, exports.askQuestion)(auth_config_1.COMMANDS.auth.options.password.description, null, { hideEchoBack: true });
    }
    while (!data.iterationCount || Number.isNaN(+data.iterationCount)) {
        data.iterationCount = (0, exports.askQuestion)(auth_config_1.COMMANDS.auth.options.itr.description, auth_config_1.COMMANDS.auth.options.itr.default.toString());
        if (data.iterationCount) {
            if (Number.isNaN(+data.iterationCount)) {
                (0, logger_1.error)('Please Enter a Number');
            }
        }
    }
    (0, logger_1.printBox)(`Server: ${data.host}`, `Username: ${data.username}`, `Password: ******`, `Iteration Count: ${data.iterationCount}`);
    return data;
};
exports.askForPAMCreds = askForPAMCreds;
