"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getErrorMessage = exports.PAMError = void 0;
const logger_1 = require("./logger");
class PAMError extends Error {
    constructor(_message, pamResponse = null) {
        const errorMessage = getErrorMessage(_message, pamResponse) || '';
        if (errorMessage) {
            (0, logger_1.error)(errorMessage);
        }
        super(errorMessage);
        this.pam_errors = [];
        this.name = 'PAMError';
        if (pamResponse === null || pamResponse === void 0 ? void 0 : pamResponse.errors) {
            this.pam_errors = pamResponse.errors;
        }
        Object.setPrototypeOf(this, PAMError.prototype);
    }
}
exports.PAMError = PAMError;
function getErrorMessage(_message, response = null) {
    let message = _message;
    if (response === null || response === void 0 ? void 0 : response.message) {
        message += ` PAM Server Error: ${response.message}`;
    }
    return message || '';
}
exports.getErrorMessage = getErrorMessage;
