"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decryptString = exports.encryptString = exports.readPackageJSON = exports.getHashedPassword = void 0;
const crypto_js_1 = require("crypto-js");
const fs_1 = __importDefault(require("fs"));
const logger_1 = require("./logger");
const config_1 = require("../constants/config");
const generateSHA512 = (_str, _iteration) => {
    if (_iteration < 1) {
        return _str;
    }
    return generateSHA512((0, crypto_js_1.SHA512)(_str).toString().toLowerCase(), _iteration - 1);
};
const getHashedPassword = (password, iteration) => generateSHA512(password, +iteration);
exports.getHashedPassword = getHashedPassword;
const readPackageJSON = () => {
    try {
        const packageJSON = fs_1.default.readFileSync('package.json', 'utf8');
        return JSON.parse(packageJSON);
    }
    catch (err) {
        if (err) {
            (0, logger_1.error)('Error reading package.json: ' + err.message);
            process.exit(1);
        }
        return null;
    }
};
exports.readPackageJSON = readPackageJSON;
function encryptString(inputString, secretKey = config_1.ENCRYPTION.secret) {
    return crypto_js_1.AES.encrypt(inputString, secretKey).toString();
}
exports.encryptString = encryptString;
function decryptString(ciphertext, secretKey = config_1.ENCRYPTION.secret) {
    const bytes = crypto_js_1.AES.decrypt(ciphertext, secretKey);
    return bytes.toString(crypto_js_1.enc.Utf8);
}
exports.decryptString = decryptString;
