"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeCredentials = exports.retrieveCredentials = exports.saveCredentials = exports.remove = exports.retrieve = exports.store = void 0;
const keytar_1 = __importDefault(require("keytar"));
const config_1 = require("../constants/config");
const logger_1 = require("./logger");
const _1 = require(".");
function store(account, data) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield keytar_1.default.setPassword(config_1.KEYCHAIN.service, account, data);
        }
        catch (err) {
            (0, logger_1.error)('Error storing: ' + err.message);
        }
    });
}
exports.store = store;
function retrieve(account) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const data = yield keytar_1.default.getPassword(config_1.KEYCHAIN.service, account);
            return data || '';
        }
        catch (err) {
            (0, logger_1.error)('Error retrieving: ' + err.message);
            return '';
        }
    });
}
exports.retrieve = retrieve;
function remove(account) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield keytar_1.default.deletePassword(config_1.KEYCHAIN.service, account);
        }
        catch (err) {
            (0, logger_1.error)('Error removing: ' + err.message);
        }
    });
}
exports.remove = remove;
function saveCredentials(server, username, token, extra = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const data = JSON.stringify(Object.assign({ server,
            username,
            token }, extra));
        const encryptedData = (0, _1.encryptString)(data);
        return store('pam_cli_credentials', encryptedData);
    });
}
exports.saveCredentials = saveCredentials;
function retrieveCredentials() {
    return __awaiter(this, void 0, void 0, function* () {
        const data = yield retrieve('pam_cli_credentials');
        if (data) {
            const decryptedData = (0, _1.decryptString)(data);
            return JSON.parse(decryptedData);
        }
        return null;
    });
}
exports.retrieveCredentials = retrieveCredentials;
function removeCredentials() {
    return __awaiter(this, void 0, void 0, function* () {
        return remove('pam_cli_credentials');
    });
}
exports.removeCredentials = removeCredentials;
